/**
 * Modify `class`: determine `class`.
 *
 * Usage:
 *
 * ```javascript
 * const dom = document.querySelector('#box');
 *
 * // Determine `class`
 * hasClass(dom, 'test');
 * // Add `class`
 * addClass(dom, 'test');
 * // Remove `class`
 * removeClass(dom, 'test');
 * ```
 *
 * @category DOM
 */
export declare function hasClass(obj: HTMLElement, cls: string): boolean;
/**
 * Modify `class`: add `class`.
 *
 * Usage:
 *
 * ```javascript
 * const dom = document.querySelector('#box');
 *
 * // Determine `class`
 * hasClass(dom, 'test');
 * // Add `class`
 * addClass(dom, 'test');
 * // Remove `class`
 * removeClass(dom, 'test');
 * ```
 *
 * @category DOM
 */
export declare function addClass(obj: HTMLElement, cls: string): void;
/**
 * Alias of `addClass`.
 *
 * @hidden
 */
export declare function setClass(obj: HTMLElement, cls: string): void;
/**
 * Modify `class`: remove `class`.
 *
 * Usage:
 *
 * ```javascript
 * const dom = document.querySelector('#box');
 *
 * // Determine `class`
 * hasClass(dom, 'test');
 * // Add `class`
 * addClass(dom, 'test');
 * // Remove `class`
 * removeClass(dom, 'test');
 * ```
 *
 * @category DOM
 */
export declare function removeClass(obj: HTMLElement, cls: string): void;
/**
 * EN: Add `<style>` in `<head>`.
 *
 * ZH: 添加样式标签; style: 样式标签内的字符串; id: `<style>` 标签的 `id`; 返回: 添加成功/失败。
 *
 * Example 1: Add the `<style>` with `id`, and repeated invoking will update the content instead of adding a new one.
 *
 * ```javascript
 * addStyle(
 *   `
 *     body {
 *       background-color: #333;
 *     }
 *   `,
 *   {
 *     id: 'test',
 *   }
 * );
 * // <style id="test">
 * //   body {
 * //     background-color: #333;
 * //   }
 * // </style>
 * ```
 *
 * Example 2: Add the `<style>` without `id`, and repeated invoking will add a new one.
 *
 * ```javascript
 * addStyle(
 *   `
 *     body {
 *       background-color: #444;
 *     }
 *   `
 * );
 * // <style>
 * //   body {
 * //     background-color: #444;
 * //   }
 * // </style>
 * ```
 *
 * @category DOM
 */
export declare function addStyle(style: string, options?: {
    id?: string;
}): boolean;
/**
 * Sets the width and height of all images on the page based on their `src` attribute.
 * The `src` attribute should contain `width` and/or `height` values in the format "width=100" or "height=100".
 * If jQuery is available, this function uses jQuery to select the images. Otherwise, it uses pure JavaScript.
 *
 * Usage:
 *
 * ```javascript
 * // Example images with `src` attributes containing `width` and/or `height` values
 * const img1 = document.createElement('img');
 * img1.setAttribute('src', 'https://example.com/example.png?width=2233&height=111');
 * document.body.appendChild(img1);
 *
 * const img2 = document.createElement('img');
 * img2.setAttribute('src', 'https://example.com/example.png?width=100%&height=auto');
 * document.body.appendChild(img2);
 * ```
 *
 * @returns {boolean} - Returns `true` if images were found and their dimensions were set, otherwise `false`.
 * @category DOM
 */
export declare function setImgSizeBySrc(): boolean;
/**
 * Alias of `setImgSizeBySrc`.
 *
 * @hidden
 */
export declare function setImgWidHeiBySrc(): boolean;
/**
 * Generate the inline style string from the given parameters. The first parameter is the query selector, and the second parameter is the style array.
 *
 * Usage:
 *
 * ```javascript
 * const ret1 = genStyleString('.a', [ 'color:red' ]);
 * const ret2 = genStyleString('#b', [ 'color:red', 'font-size:12px' ]);
 * console.log(ret1);
 * console.log(ret2);
 * ```
 *
 * Output:
 *
 * ```text
 * .a{color:red;}
 * #b{color:red;font-size:12px;}
 * ```
 *
 * @param {string} selector
 * @param {array} styleArray
 * @returns {string} The inline style string.
 * @category DOM
 */
export declare function genStyleString(selector: string, styleArray: Array<string>): string;
//# sourceMappingURL=dom.d.ts.map