import type { WebPerformance } from "./typing";
/**
 * @hidden
 */
export declare function isSupportedEntryType(name: string): boolean;
/**
 * Gets the first contentful paint (FCP) time of a web page using the Performance API.
 * The FCP time is the time it takes for the first piece of content to be painted on the screen.
 *
 * Usage:
 *
 * ```javascript
 * getFCP().then(
 *  res => {
 *   console.log(`FCP: ${res}`);
 *  }
 * );
 * ```
 *
 * Output:
 *
 * ```text
 * FCP: 123
 * ```
 *
 * @returns A promise that resolves with the FCP time in milliseconds, or 0 if the 'paint' entry type is not supported.
 * @category Perf
 */
export declare function getFCP(): Promise<number>;
/**
 * Gets the first paint (FP) time of a web page using the Performance API.
 * The FP time is the time it takes for the first pixel to be painted on the screen.
 *
 * Usage:
 *
 * ```javascript
 * getFP().then(
 *  res => {
 *    console.log(`FP: ${res}`);
 *  }
 * );
 * ```
 *
 * Output:
 *
 * ```text
 * FP: 123
 * ```
 *
 * @returns A promise that resolves with the FP time in milliseconds, or 0 if the 'paint' entry type is not supported.
 * @category Perf
 */
export declare function getFP(): Promise<number>;
/**
 * Gets the largest contentful paint (LCP) time of a web page using the Performance API.
 * The LCP time is the time it takes for the largest piece of content to be painted on the screen.
 *
 * Usage:
 *
 * ```javascript
 * getLCP().then(
 *  res => {
 *    console.log(`LCP: ${res}`);
 *  }
 * );
 * ```
 *
 * Output:
 *
 * ```text
 * LCP: 123
 * ```
 *
 * @returns A promise that resolves with the LCP time in milliseconds, or 0 if the 'largest-contentful-paint' entry type is not supported.
 * @category Perf
 */
export declare function getLCP(): Promise<number>;
/**
 * Gets the first input delay (FID) of a web page using the Performance API.
 * The FID is the time it takes for the first user input to be processed by the browser.
 *
 * Usage:
 *
 * ```javascript
 * getFID().then(
 *  res => {
 *    console.log(`FID: ${res}`);
 *  }
 * );
 * ```
 *
 * Output:
 *
 * ```text
 * FID: 123
 * ```
 *
 * @returns A promise that resolves with the FID in milliseconds, or 0 if the 'first-input' entry type is not supported.
 * @category Perf
 */
export declare function getFID(): Promise<number>;
/**
 * Gets the Cumulative Layout Shift (CLS) score of a web page using the Performance API.
 * The CLS score is a measure of how much the page layout shifts during loading.
 *
 * Usage:
 *
 * ```javascript
 * getCLS().then(
 *  res => {
 *    console.log(`CLS: ${res}`);
 *  }
 * );
 * ```
 *
 * Output:
 *
 * ```text
 * CLS: 123
 * ```
 *
 * @returns A promise that resolves with the CLS score, or 0 if the 'layout-shift' entry type is not supported.
 * @category Perf
 */
export declare function getCLS(): Promise<number>;
/**
 * Gets the time to first byte (TTFB) of a web page using the Performance API.
 * The TTFB is the time it takes for the first byte of the response to be received by the browser.
 *
 * Usage:
 *
 * ```javascript
 * getTTFB().then(
 *  res => {
 *    console.log(`TTFB: ${res}`);
 *  }
 * );
 * ```
 *
 * Output:
 *
 * ```text
 * TTFB: 123
 * ```
 *
 * @returns The TTFB in milliseconds, or 0 if the navigation timing information is not available.
 * @category Perf
 */
export declare function getTTFB(): Promise<number>;
/**
 * EN: Get page load time(`PerformanceNavigationTiming`).
 *
 * ZH: 获取页面加载相关的各项数据。
 *
 * @remarks
 * This function uses the [`PerformanceNavigationTiming`](https://developer.mozilla.org/en-US/docs/Web/API/PerformanceNavigationTiming) API to get page load time data.
 * The `PerformanceNavigationTiming` API provides more accurate and detailed information about page load time than the deprecated [`PerformanceTiming`](https://developer.mozilla.org/en-US/docs/Web/API/PerformanceTiming) API.
 * If you are using an older browser that does not support `PerformanceNavigationTiming`, you can still use the `PerformanceTiming` API by using the previous version of this library ([`v3.9.7`](https://github.com/mazeyqian/mazey/releases/tag/v3.9.7)).
 *
 * Usage:
 *
 * ```javascript
 * // `camelCase：false` (Default) Return underline(`a_b`) data.
 * // `camelCase：true` Return hump(`aB`) data.
 * getPerformance()
 *  .then(res => {
 *   console.log(JSON.stringify(res));
 *  })
 *  .catch(console.error);
 * ```
 *
 * Output:
 *
 * ```text
 * {"source":"PerformanceNavigationTiming","os":"others","os_version":"","device_type":"pc","network":"4g","screen_direction":"","unload_time":0,"redirect_time":0,"dns_time":0,"tcp_time":0,"ssl_time":0,"response_time":2,"download_time":2,"first_paint_time":288,"first_contentful_paint_time":288,"dom_ready_time":0,"onload_time":0,"white_time":0,"render_time":0,"decoded_body_size":718,"encoded_body_size":718}
 * ```
 *
 * Results:
 *
 * | Attribute | Description | Type | Values |
 * | :------------ | :------------ | :------------ | :------------ |
 * | dns_time | DNS Lookup | number | domainLookupEnd - domainLookupStart |
 * | tcp_time | Connection Negotiation | number | connectEnd - connectStart |
 * | response_time | Requests and Responses | number | responseStart - requestStart |
 * | white_time | White Screen | number | responseStart - navigationStart |
 * | dom_ready_time | Dom Ready | number | domContentLoadedEventStart - navigationStart |
 * | onload_time | Onload | number | loadEventStart - navigationStart |
 * | render_time | EventEnd | number | loadEventEnd -navigationStart |
 * | unload_time | Unload | number | (Optional) unloadEventEnd - unloadEventStart |
 * | redirect_time | Redirect | number | (Optional) redirectEnd - redirectStart |
 * | ssl_time | SSL | number | (Optional) connectEnd - secureConnectionStart |
 * | download_time | Download | number | (Optional) responseEnd - responseStart |
 *
 * @param {boolean} camelCase -- false（默认） 以下划线形式返回数据 true 以驼峰形式返回数据
 * @returns {Promise<object>} 加载数据
 * @category Perf
 */
export declare function getPerformance(camelCase?: boolean): Promise<WebPerformance | Error>;
//# sourceMappingURL=perf.d.ts.map