/**
 * Get the query param's value of the current Web URL(`location.search`).
 *
 * Usage:
 *
 * ```javascript
 * // http://example.com/?t1=1&t2=2&t3=3&t4=4#2333
 * // ?t1=1&t2=2&t3=3&t4=4
 * const p1 = getQueryParam('t3');
 * const p2 = getQueryParam('t4');
 * console.log(p1, p2);
 * ```
 *
 * Output:
 *
 * ```text
 * 3 4
 * ```
 *
 * @param {string} param Query param.
 * @returns {string} value
 * @category URL
 */
export declare function getQueryParam(param: string): string;
/**
 * Returns the value of the specified query parameter in the input URL.
 *
 * Usage:
 *
 * ```javascript
 * const p1 = getUrlParam('http://example.com/?t1=1&t2=2&t3=3&t4=4', 't3');
 * const p2 = getUrlParam('http://example.com/?t1=1&t2=2&t3=3&t4=4', 't4');
 * console.log(p1, p2);
 * ```
 *
 * Output:
 *
 * ```text
 * 3 4
 * ```
 *
 * @param {string} url The URL string.
 * @param {string} param The query parameter to retrieve the value for.
 * @param {object} options The options object.
 * @param {boolean} options.returnArray Whether to return an array of values for the specified query parameter. Default is false.
 * @returns {string|string[]} The value of the specified query parameter, or an empty string if the parameter is not found.
 * @category URL
 */
export declare function getUrlParam(url: string, param: string, options?: {
    returnArray?: boolean;
}): string | string[] | null;
/**
 * Update the query param's value of the input URL.
 *
 * Usage:
 *
 * ```javascript
 * const ret1 = updateQueryParam('http://example.com/?t1=1&t2=2&t3=3&t4=4', 't3', 'three');
 * const ret2 = updateQueryParam('http://example.com/?t1=1&t2=2&t3=3&t4=4', 't4', 'four');
 * console.log(ret1);
 * console.log(ret2);
 * ```
 *
 * Output:
 *
 * ```text
 * http://example.com/?t1=1&t2=2&t3=three&t4=4
 * http://example.com/?t1=1&t2=2&t3=3&t4=four
 * ```
 *
 * @param {string} url URL string.
 * @param {string} param Query param.
 * @param {string} value Param's value.
 * @returns {string} URL.
 * @category URL
 */
export declare function updateQueryParam(url: string, param: string, value: string): string;
/**
 * Get the hash query param's value of the current Web URL(`location.hash`).
 *
 * Usage:
 *
 * ```javascript
 * // http://example.com/?#2333?t1=1&t2=2&t3=3&t4=4
 * // #2333?t1=1&t2=2&t3=3&t4=4
 * const p1 = getHashQueryParam('t3');
 * const p2 = getHashQueryParam('t4');
 * console.log(p1, p2);
 * ```
 *
 * Output:
 *
 * ```text
 * 3 4
 * ```
 *
 * @param {string} param Query param.
 * @returns {string} value
 * @category URL
 */
export declare function getHashQueryParam(param: string): string;
/**
 * Get the domain of URL, and other params.
 *
 * Usage:
 *
 * ```javascript
 * const ret1 = getDomain('http://example.com/?t1=1&t2=2&t3=3&t4=4');
 * const ret2 = getDomain('http://example.com/test/thanks?t1=1&t2=2&t3=3&t4=4', ['hostname', 'pathname']);
 * const ret3 = getDomain('http://example.com:7890/test/thanks', ['hostname']);
 * const ret4 = getDomain('http://example.com:7890/test/thanks', ['host']); // With Port
 * const ret5 = getDomain('http://example.com:7890/test/thanks', ['origin']);
 * const ret6 = getDomain('http://example.com:7890/test/thanks?id=1', ['origin', 'pathname', 'search']);
 * console.log(ret1);
 * console.log(ret2);
 * console.log(ret3);
 * console.log(ret4);
 * console.log(ret5);
 * console.log(ret6);
 * ```
 *
 * Output:
 *
 * ```text
 * example.com
 * example.com/test/thanks
 * example.com
 * example.com:7890
 * http://example.com:7890
 * http://example.com:7890/test/thanks?id=1
 * ```
 *
 * @param {string} url
 * @param {array} rules Object.keys(location), ['href', 'origin', 'protocol', 'host', 'hostname', 'port', 'pathname', 'search', 'hash'], ['hostname', 'pathname'] = 'km.mazey.net/plugins/servlet/mobile'
 * @category URL
 */
export declare function getDomain(url: string, rules?: string[]): string;
/**
 * Checks if the given string is a valid URL, including **scheme URLs**.
 *
 * Usage:
 *
 * ```javascript
 * const ret1 = isValidUrl('https://www.example.com');
 * const ret2 = isValidUrl('http://example.com/path/exx/ss');
 * const ret3 = isValidUrl('https://www.example.com/?q=hello&age=24#world');
 * const ret4 = isValidUrl('http://www.example.com/#world?id=9');
 * const ret5 = isValidUrl('ftp://example.com');
 * console.log(ret1, ret2, ret3, ret4, ret5);
 * ```
 *
 * Output:
 *
 * ```text
 * true true true true true
 * ```
 *
 * @remarks
 * If you are specifically checking for HTTP/HTTPS URLs, it is recommended to use the `isValidHttpUrl` function instead.
 * The `isValidUrl` function matches all scheme URLs, including FTP and other non-HTTP schemes.
 *
 * @param url - The URL to check.
 * @returns Returns `true` if the given string is a valid URL, else `false`.
 * @category URL
 */
export declare function isValidUrl(url: string): boolean;
/**
 * Check if the given string is a valid HTTP/HTTPS URL.
 *
 * Usage:
 *
 * ```javascript
 * const ret1 = isValidHttpUrl('https://www.example.com');
 * const ret2 = isValidHttpUrl('http://example.com/path/exx/ss');
 * const ret3 = isValidHttpUrl('https://www.example.com/?q=hello&age=24#world');
 * const ret4 = isValidHttpUrl('http://www.example.com/#world?id=9');
 * const ret5 = isValidHttpUrl('//example.com/a/b/c?q=1', { strict: false });
 * const ret6 = isValidHttpUrl('ftp://example.com');
 * console.log(ret1, ret2, ret3, ret4, ret5, ret6);
 * ```
 *
 * Output:
 *
 * ```text
 * true true true true true false
 * ```
 *
 * @param url
 * @param options.strict - If `true`, the function only matches standard HTTP/HTTPS URLs. Default is `true`. If `false`, the function also matches protocol-relative URLs, such as `//example.com`.
 * @returns {boolean} Return true if the given string is a valid HTTP/HTTPS URL.
 * @category URL
 */
export declare function isValidHttpUrl(url: string, options?: {
    strict: boolean;
}): boolean;
/**
 * EN: Get the file type of the url.
 *
 * ZH: 获取文件后缀名。
 *
 * Usage:
 *
 * ```javascript
 * const ret1 = getUrlFileType('https://example.com/a/b/c.png');
 * const ret2 = getUrlFileType('https://example.com/a/b/c.jpg');
 * const ret3 = getUrlFileType('https://example.com/a/b/c.jpeg');
 * const ret4 = getUrlFileType('/a/b/c.jpeg');
 * const ret5 = getUrlFileType('https://example.com/a/b/c.v/a');
 * console.log(ret1, ret2, ret3, ret4, ret5);
 * ```
 *
 * Output:
 *
 * ```text
 * png jpg jpeg jpeg ''
 * ```
 *
 * @param url
 * @returns
 * @category URL
 */
export declare function getUrlFileType(url: string): boolean | string;
/**
 * Retrieve a query parameter from a script URL in the browser.
 *
 * Usage:
 *
 * ```javascript
 * const ret = getScriptQueryParam('test', 'https://example.com/example.js');
 * console.log(ret);
 * ```
 *
 * Output:
 *
 * ```text
 * hello
 * ```
 *
 * @param param - The name of the query parameter to retrieve.
 * @param matchString - An optional substring to match in the script URL.
 *                      If not provided, defaults to matching the ".js" substring.
 * @returns The decoded value of the specified query parameter, or an empty string if no matching parameter is found.
 * @category URL
 */
export declare function getScriptQueryParam(param: string, matchString?: string): string;
/**
 * Convert an object to a query string.
 *
 * Usage:
 *
 * ```javascript
 * const ret = convertObjectToQuery({ t1: '1', t2: '2', t3: '3', t4: '4' });
 * console.log(ret);
 * ```
 *
 * Output:
 *
 * ```text
 * ?t1=1&t2=2&t3=3&t4=4
 * ```
 *
 * @param obj - The object to convert to a query string.
 * @returns The query string.
 * @category URL
 */
export declare function convertObjectToQuery(obj: {
    [key: string]: string;
}): string;
/**
 * Convert an HTTP URL to an HTTPS URL.
 *
 * Usage:
 *
 * ```javascript
 * const ret = convertHttpToHttps('http://example.com');
 * console.log(ret);
 * ```
 *
 * Output:
 *
 * ```text
 * https://example.com
 * ```
 *
 * @param url - The HTTP URL to convert to HTTPS.
 * @returns The HTTPS URL.
 * @category URL
 */
export declare function convertHttpToHttps(url: string): string;
/**
 * Alias of `convertHttpToHttps`.
 *
 * @hidden
 */
export declare function replaceHttp(url: string): string;
//# sourceMappingURL=url.d.ts.map